LiquidButton class

Returns a Material Button or a Cupertino Button based on platform

Inheritance

Constructors

LiquidButton({required String name, double fontSize = 19, double width = 88, double height = 36, required dynamic onPressed(), Color? backgroundColor, Key? key})
The only required fields are name and onPressed

Properties

backgroundColor → Color?
color of the background
final
fontSize → double
Font size of the button text
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
the height of the button
final
key → Key?
key for the button - optional
final
name → String
the text in the center of the button
final
onPressed → dynamic Function()
function to call on the button press
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
the overall width of the button
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited